# Dais-SDK

Dais-SDK is a LLM Agent Meta Framework.

## Installation

```
pip install dais_sdk
```

## Development

Create virtual environment
```
uv venv
```

Install all dependencies
```
uv sync --all-groups
```

Run test
```
uv run pytest
```
